aboutsummaryrefslogtreecommitdiff
path: root/src/soc/intel
diff options
context:
space:
mode:
Diffstat (limited to 'src/soc/intel')
-rw-r--r--src/soc/intel/meteorlake/p2sb.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/soc/intel/meteorlake/p2sb.c b/src/soc/intel/meteorlake/p2sb.c
index ae9b9a403c..5863cf0fd7 100644
--- a/src/soc/intel/meteorlake/p2sb.c
+++ b/src/soc/intel/meteorlake/p2sb.c
@@ -34,8 +34,8 @@ void p2sb_soc_get_sb_mask(uint32_t *ep_mask, size_t count)
static void ioe_p2sb_read_resources(struct device *dev)
{
- /* Add the fixed MMIO resource for IOM */
- mmio_range(dev, PCI_BASE_ADDRESS_0, IOM_BASE_ADDR, IOM_BASE_SIZE);
+ /* Add the fixed MMIO resource for IOE P2SB */
+ mmio_range(dev, PCI_BASE_ADDRESS_0, IOE_P2SB_BAR, IOE_P2SB_SIZE);
}
static void p2sb_read_resources(struct device *dev)